<no title> — CALCEPH - Python language 3.4.1 documentation

The order of derivatives.

> - = 0 , only the angular momentum is computed. The first three numbers of PVAJ are valid for the results.
> - = 1 , only the angular momentum and the first derivative are computed. The first six numbers of PVAJ are valid for the results.
> - = 2 , only the angular momentum and the first and second derivatives are computed. The first nine numbers of PVAJ are valid for the results.
> - = 3 , the angular momentum and the first, second and third derivatives are computed. The first twelve numbers of PVAJ are valid for the results.

If order equals to 1, the behavior of `calcephpy.CalcephBin.rotangmom_order()` is the same as `calcephpy.CalcephBin.rotangmom_unit()`.